Download assets from the STAC API on the geodata catalog of the Swiss Confederation (https://data.geo.admin.ch/api/stac/v0.9/).
bfs_download_geodata(
collection_id = collection_id,
output_dir = tempdir(),
overwrite = FALSE,
create_json = FALSE,
bbox = NULL,
asset_names = NULL,
datetime = NULL,
feature_id = NULL
)Returns the file path where the file has been downloaded. Returns NULL if no connection.
collection_id
output_dir
overwrite
create_json
bbox
asset_names
datetime
feature_id
The use of the data and services is free but subject to the provisions on fair use (see https://www.geo.admin.ch/terms-of-use).