Learn R Programming

BFS (version 0.7.1)

bfs_get_sse_metadata: Get Metadata (Codelists) from Swiss Stats Explorer (SSE) API

Description

Retrieve metadata codelists for a specified BFS dataset from the Swiss Stats Explorer (SSE) API. This function is required to built queries for bfs_get_sse_data.

Usage

bfs_get_sse_metadata(number_bfs, language = "de")

Value

A tibble containing the codelists of the specified BFS dataset.

Arguments

number_bfs

The BFS number (FSO number) of a dataset.

language

Language of the codelists ("de", "fr", "it", "en").

Examples

Run this code
bfs_get_sse_metadata("DF_SSV_POL_LEG", language = "de")

Run the code above in your browser using DataLab